'use client'

import { useState, useEffect } from 'react'
import { FiSave } from 'react-icons/fi'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { useParams } from 'next/navigation'
import { categoryService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { useRouter } from 'next/navigation'
import Modal from '@/components/ui/Modal'

export default function EditCategoryPage() {
  const params = useParams()
  const id = params?.id as string // params'ı güvenli bir şekilde kullan
  const { user } = useUser()
  const router = useRouter()
  const [formData, setFormData] = useState({
    name: '',
  })
  const [success, setSuccess] = useState(false)
  const [error, setError] = useState(false)

  useEffect(() => {
    const fetchCategory = async () => {
      try {
        const response = await categoryService.show(id, user?.token || '')
        setFormData(response.data.category)
      } catch (err) {
        setError(true)
      }
    }

    if (id && user?.token) {
      fetchCategory()
    }
  }, [id, user?.token])

  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    const { name, value } = e.target
    setFormData(prev => ({
      ...prev,
      [name]: value
    }))
  }

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    try {
      await categoryService.update(id, formData.name, user?.token || '')
      setSuccess(true)
      setTimeout(() => {
        router.push('/dashboard/categories')
      }, 1500)
    } catch (err) {
      setError(true)
    }
  }

  return (
    <DashboardLayout>
      <div className="w-full mx-auto">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg 
                     border border-slate-200/50 dark:border-slate-700/50">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <h2 className="text-xl font-bold text-slate-800 dark:text-white">
              Kategori Düzenle
            </h2>
            <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
              Kategori bilgilerini güncellemek için formu kullanın
            </p>
          </div>

          <form onSubmit={handleSubmit} className="p-6 space-y-6">
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
              {/* Kategori Adı */}
              <div>
                <label htmlFor="name" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Kategori Adı
                </label>
                <input
                  id="name"
                  name="name"
                  type="text"
                  value={formData.name}
                  onChange={handleInputChange}
                  className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                           bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                           text-slate-800 dark:text-white
                           focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                           transition-all"
                  required
                />
              </div>

            </div>

            {/* Kaydet Butonu */}
            <div className="flex justify-end">
              <button
                type="submit"
                className="px-6 py-2.5 text-sm font-medium text-white
                       bg-gradient-to-r from-fuchsia-500 to-purple-600
                       rounded-xl hover:opacity-90 transition-all
                       flex items-center gap-2"
              >
                <FiSave className="w-4 h-4" />
                Kaydet
              </button>
            </div>
          </form>
        </div>
      </div>
      <Modal
        isOpen={success}
        onClose={() => setSuccess(false)}
        title="Başarılı"
        message="Kategori başarıyla güncellendi yönlendiriliyorsunuz..."
      />
      <Modal
        isOpen={error}
        onClose={() => setError(false)}
        title="Hata"
        message="Kategori güncellenirken bir hata oluştu"
      />

    </DashboardLayout>
  )
} 